<?php
/**
* This class is loaded on the back-end since its main job is
* to display the Admin to box.
*/
class GMBPU_Table_Filter {
	
	public function GMBPU_Filter(){

        $tax_classes = WC_Tax::get_tax_classes();

        array_unshift($tax_classes, 'Standard'); 
        
        $formatted_tax_classes = array_map(function($tax_class) {
            //print_r($tax_class);
            $tax_class_label = $tax_class ? ucwords(str_replace('_', ' ', $tax_class)) : 'Standard';
            return array(
                'label' => $tax_class_label,
                'value' => strtolower(str_replace(' ', '-', $tax_class))
            );
        }, $tax_classes);
        $product_statuses = get_post_statuses();
         $formatted_product_statuses = array_map(function($label, $value) {
            return array(
                'label' => $label, // Human-readable label (e.g., "Published")
                'value' => $value  // Raw status value (e.g., "publish")
            );
        }, $product_statuses, array_keys($product_statuses));

        $product_types = wc_get_product_types();

        $formatted_product_types = array_map(function($label, $value) {
            return array(
                'label' => $label, // Human-readable label (e.g., "Simple product")
                'value' => $value  // Raw type value (e.g., "simple")
            );
        }, $product_types, array_keys($product_types));

        $product_cat = get_terms('product_cat', array(
            'hide_empty' => false,
        ));

        $formatted_product_cat = array_map(function ($term) {
            return [
                'label' => $term->name,  // Category name as label
                'value' => $term->term_id, // Category ID as value
            ];
        }, $product_cat);

        $product_tag = get_terms('product_tag', array(
            'hide_empty' => false,
        ));

        $formatted_product_tag = array_map(function ($term) {
            return [
                'label' => $term->name,  // Category name as label
                'value' => $term->term_id, // Category ID as value
            ];
        }, $product_tag);


        $columns = [
            ['title' => 'Product ID', 'accessor' => 'id', 'inputType' => 'text'],
            ['title' => 'Product Title', 'accessor' => 'name', 'inputType' => 'text'],
            ['title' => 'Product Slug', 'accessor' => 'slug', 'inputType' => 'text'],
            ['title' => 'Product Content', 'accessor' => 'content', 'inputType' => 'text'],
            ['title' => 'SKU', 'accessor' => '_sku', 'inputType' => 'text'],
            ['title' => 'Publish Date From', 'accessor' => '_publish_date_from', 'inputType' => 'datetime-local'],
            ['title' => 'Publish Date To', 'accessor' => '_publish_date_to', 'inputType' => 'datetime-local'],
            ['title' => 'Regular Price From', 'accessor' => '_regular_price_from', 'inputType' => 'number'],
            ['title' => 'Regular Price To', 'accessor' => '_regular_price_to', 'inputType' => 'number'],
            ['title' => 'Sale Price From', 'accessor' => '_sale_price_from', 'inputType' => 'number'],
            ['title' => 'Sale Price To', 'accessor' => '_sale_price_to', 'inputType' => 'number'],
            ['title' => 'Stock QTY From', 'accessor' => '_stock_qty_from', 'inputType' => 'number'],
            ['title' => 'Stock QTY To', 'accessor' => '_stock_qty_to', 'inputType' => 'number'],
            [
                'title' => 'Stock Status',
                'accessor' => '_stock_status',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'In Stock', 'value' => 'instock'],
                    ['label' => 'Out of Stock', 'value' => 'outofstock'],
                    ['label' => 'On backorder', 'value' => 'onbackorder'],
                ],
            ],
            [
                'title' => 'Product Category',
                'accessor' => '_product_category',
                'inputType' => 'multipleCheckbox',
                'options' => $formatted_product_cat,
            ],
            [
                'title' => 'Product Tag',
                'accessor' => '_product_tag',
                'inputType' => 'multipleCheckbox',
                'options' => $formatted_product_tag,
            ],
            
            [
                'title' => 'Allow backorders',
                'accessor' => '_backorders',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'yes', 'value' => 'yes'],
                    ['label' => 'notify', 'value' => 'notify'],
                    ['label' => 'no', 'value' => 'no'],
                ],
            ],
            [
                'title' => 'Status',
                'accessor' => '_status',
                'inputType' => 'select',
                'options' => $formatted_product_statuses,
            ],[
                'title' => 'Product Type',
                'accessor' => '_product_type',
                'inputType' => 'select',
                'options' => $formatted_product_types,
            ],[
                'title' => 'Visibility',
                'accessor' => '_visibility',
                'inputType' => 'select',
                'options' => [
                	['label' => 'Visible', 'value' => 'visible'],
                    ['label' => 'Catalog', 'value' => 'catalog'],
                    ['label' => 'Hidden', 'value' => 'hidden'],
                    ['label' => 'Search', 'value' => 'search'],
                ],
            ],
            [
                'title' => 'Tax Status',
                'accessor' => '_tax_status',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'Taxable', 'value' => 'taxable'],
                    ['label' => 'Shipping', 'value' => 'shipping'],
                    ['label' => 'None', 'value' => 'none'],
                ],
            ],
            [
                'title' => 'Tax Classes',
                'accessor' => '_tax_class',
                'inputType' => 'select',
                'options' => $formatted_tax_classes,
            ],
            ['title' => 'Stock', 'accessor' => '_stock', 'inputType' => 'number'],
            [
                'title' => 'Featured',
                'accessor' => '_featured',
                'inputType' => 'checkbox'
            ],
            [
                'title' => 'Virtual',
                'accessor' => '_virtual',
                'inputType' => 'checkbox'
            ],
        ];
        return $columns ;
    }
}
