<?php
/**
* This class is loaded on the back-end since its main job is
* to display the Admin to box.
*/
class GMBPU_Table_Header {
	
	public function GMBPU_header($data){

        $tax_classes = WC_Tax::get_tax_classes();

        array_unshift($tax_classes, 'Standard'); 
        
        $formatted_tax_classes = array_map(function($tax_class) {
            //print_r($tax_class);
            $tax_class_label = $tax_class ? ucwords(str_replace('_', ' ', $tax_class)) : 'Standard';
            return array(
                'label' => $tax_class_label,
                'value' => strtolower(str_replace(' ', '-', $tax_class))
            );
        }, $tax_classes);
        $product_statuses = get_post_statuses();
         $formatted_product_statuses = array_map(function($label, $value) {
            return array(
                'label' => $label, // Human-readable label (e.g., "Published")
                'value' => $value  // Raw status value (e.g., "publish")
            );
        }, $product_statuses, array_keys($product_statuses));

        $product_types = wc_get_product_types();

        $formatted_product_types = array_map(function($label, $value) {
            return array(
                'label' => $label, // Human-readable label (e.g., "Simple product")
                'value' => $value  // Raw type value (e.g., "simple")
            );
        }, $product_types, array_keys($product_types));

        $product_cat = get_terms('product_cat', array(
            'hide_empty' => false,
        ));

        $formatted_product_cat = array_map(function ($term) {
            return [
                'label' => $term->name,  // Category name as label
                'value' => $term->term_id, // Category ID as value
            ];
        }, $product_cat);

        $product_tag = get_terms('product_tag', array(
            'hide_empty' => false,
        ));

        $formatted_product_tag = array_map(function ($term) {
            return [
                'label' => $term->name,  // Category name as label
                'value' => $term->term_id, // Category ID as value
            ];
        }, $product_tag);


        $columns = [
            ['Header' => 'ID', 'accessor' => 'id', 'inputType' => 'readonly'],
            ['Header' => 'Name', 'accessor' => 'name', 'inputType' => 'text'],
            ['Header' => 'Slug', 'accessor' => 'slug', 'inputType' => 'text'],
            /*['Header' => 'Price', 'accessor' => '_price', 'inputType' => 'number'],*/
            ['Header' => 'Regular Price', 'accessor' => '_regular_price', 'inputType' => 'number'],
            ['Header' => 'Sale Price', 'accessor' => '_sale_price', 'inputType' => 'number'],
            ['Header' => 'Weight (kg)', 'accessor' => '_weight', 'inputType' => 'number'],
            ['Header' => 'Length', 'accessor' => '_length', 'inputType' => 'number'],
            ['Header' => 'Width', 'accessor' => '_width', 'inputType' => 'number'],
            ['Header' => 'Height', 'accessor' => '_height', 'inputType' => 'number'],
            ['Header' => 'Download Limit', 'accessor' => '_download_limit', 'inputType' => 'number'],
            ['Header' => 'Download Expiry', 'accessor' => '_download_expiry', 'inputType' => 'number'],
            ['Header' => 'Publish Date', 'accessor' => '_publish_date', 'inputType' => 'datetime-local'],
            ['Header' => 'Description', 'accessor' => '_product_description', 'inputType' => 'editor'],
            ['Header' => 'Short Description', 'accessor' => '_product_short_description', 'inputType' => 'editor'],
            ['Header' => 'Purchase Note', 'accessor' => '_purchase_note', 'inputType' => 'editor'],
            ['Header' => 'Menu Order', 'accessor' => '_menu_order', 'inputType' => 'number'],
            ['Header' => 'Image', 'accessor' => '_image', 'inputType' => 'image'],
            ['Header' => 'Gallery', 'accessor' => '_gallery', 'inputType' => 'gallery'],
            [
                'Header' => 'Stock Status',
                'accessor' => '_stock_status',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'In Stock', 'value' => 'instock'],
                    ['label' => 'Out of Stock', 'value' => 'outofstock'],
                    ['label' => 'On backorder', 'value' => 'onbackorder'],
                ],
            ],
            [
                'Header' => 'Product Category',
                'accessor' => '_product_category',
                'inputType' => 'multipleCheckbox',
                'options' => $formatted_product_cat,
            ],
            [
                'Header' => 'Product Tag',
                'accessor' => '_product_tag',
                'inputType' => 'multipleCheckbox',
                'options' => $formatted_product_tag,
            ],
            
            [
                'Header' => 'Allow backorders',
                'accessor' => '_backorders',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'yes', 'value' => 'yes'],
                    ['label' => 'notify', 'value' => 'notify'],
                    ['label' => 'no', 'value' => 'no'],
                ],
            ],
            [
                'Header' => 'Status',
                'accessor' => '_status',
                'inputType' => 'select',
                'options' => $formatted_product_statuses,
            ],[
                'Header' => 'Product Type',
                'accessor' => '_product_type',
                'inputType' => 'select',
                'options' => $formatted_product_types,
            ],[
                'Header' => 'Visibility',
                'accessor' => '_visibility',
                'inputType' => 'select',
                'options' => [
                	['label' => 'Visible', 'value' => 'visible'],
                    ['label' => 'Catalog', 'value' => 'catalog'],
                    ['label' => 'Hidden', 'value' => 'hidden'],
                    ['label' => 'Search', 'value' => 'search'],
                ],
            ],
            [
                'Header' => 'Tax Status',
                'accessor' => '_tax_status',
                'inputType' => 'select',
                'options' => [
                    ['label' => 'Taxable', 'value' => 'taxable'],
                    ['label' => 'Shipping', 'value' => 'shipping'],
                    ['label' => 'None', 'value' => 'none'],
                ],
            ],
            [
                'Header' => 'Tax Classes',
                'accessor' => '_tax_class',
                'inputType' => 'select',
                'options' => $formatted_tax_classes,
            ],
            ['Header' => 'Stock', 'accessor' => '_stock', 'inputType' => 'number'],
            ['Header' => 'SKU', 'accessor' => '_sku', 'inputType' => 'text'],
            [
                'Header' => 'Manage Stock',
                'accessor' => '_manage_stock',
                'inputType' => 'checkbox'
            ],
            [
                'Header' => 'Featured',
                'accessor' => '_featured',
                'inputType' => 'checkbox'
            ],
            [
                'Header' => 'Downloadable',
                'accessor' => '_downloadable',
                'inputType' => 'checkbox'
            ],
            [
                'Header' => 'Virtual',
                'accessor' => '_virtual',
                'inputType' => 'checkbox'
            ],
            [
                'Header' => 'Enable Reviews',
                'accessor' => '_enable_reviews',
                'inputType' => 'checkbox'
            ],
            
            [
                'Header' => 'Sold individually',
                'accessor' => '_sold_individually',
                'inputType' => 'checkbox'
            ],
            [
                'Header' => 'Attribute',
                'accessor' => '_attribute',
                'inputType' => 'attribute',
            ],
            [
                'Header' => 'Default Attribute',
                'accessor' => '_default_attribute',
                'inputType' => 'default_attribute',
            ],
        ];
        foreach($columns as $key=>$val){
            if(!empty($data['settings'])){
                /*echo $data['settings'][$key];
                print_r($data['settings']);
                 print_r($val['accessor']);*/
                 $headkey= $val['accessor'];
                if(isset($data['settings'][$headkey])){
                     $columns[$key]['isShow']=  $data['settings'][$headkey];
                }else{
                     $columns[$key]['isShow']= false;
                    // unset($columns[$key]);
                }  
            }else{
                 $columns[$key]['isShow']= true;
            } 
            
           
        }
        
        return $columns ;
    }
    
}
