<?php
/**
 * This class is loaded on the back-end since its main job is
 * to display the Admin table box.
 */
class GMBPU_Table_Query {
    public $GMBPU_Table_Value;
    public $GMBPU_Table_Header;
    public $GMBPU_Table_Filter;
    public function __construct() {
        $this->GMBPU_Table_Value = new GMBPU_Table_Value();
        $this->GMBPU_Table_Header = new GMBPU_Table_Header();
        $this->GMBPU_Table_Filter = new GMBPU_Table_Filter();
    }

    public function GMBPU_Table_Query_Data($data, $page) {
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => 50, // Reduced for better performance
            'paged'          => $page,
            'orderby'        => 'date',
            'post_status'    => array('publish', 'pending', 'draft', 'private'),
            'order'          => 'ASC',
            'meta_query'     => array('relation' => 'AND'), // Meta query for custom fields
            'tax_query'      => array(), // For categories and tags
        );

        // Apply filters if present
        if (!empty($data['filters'])) {
            foreach ($data['filters'] as $filters_key => $filters_val) {
                if (!empty($filters_val)) {

                    // Handle standard text-based filters
                    if (in_array($filters_key, ['id', 'name', 'slug', 'content'])) {
                        if ($filters_key === 'id') {
                            $args['p'] = absint($filters_val);
                        } elseif ($filters_key === 'name') {
                            $args['s'] = sanitize_text_field($filters_val);
                            add_filter('posts_search', [$this, 'search_by_title_only'], 10, 2);
                        } elseif ($filters_key === 'slug') {
                            $args['name'] = sanitize_title($filters_val);
                        } elseif ($filters_key === 'content') {
                            add_filter('posts_where', [$this, 'search_by_content_only'], 10, 2);
                            $args['s'] = sanitize_text_field($filters_val);
                        }
                    }

                    // Handle numeric filters (price, stock)
                    if (strpos($filters_key, '_from') !== false || strpos($filters_key, '_to') !== false) {
                        $compare = (strpos($filters_key, '_from') !== false) ? '>=' : '<=';
                        $meta_key = str_replace(['_from', '_to'], '', $filters_key);
                        $args['meta_query'][] = array(
                            'key'     => $meta_key,
                            'value'   => floatval($filters_val),
                            'type'    => 'NUMERIC',
                            'compare' => $compare
                        );
                    }

                    // Handle Select Fields
                    if (in_array($filters_key, ['_stock_status', '_backorders', '_status', '_product_type', '_visibility', '_tax_status', '_tax_class'])) {
                        $args['meta_query'][] = array(
                            'key'     => $filters_key,
                            'value'   => sanitize_text_field($filters_val),
                            'compare' => '='
                        );
                    }

                    // Handle Checkbox Fields (Boolean)
                    if (in_array($filters_key, ['_featured', '_virtual'])) {
                        $args['meta_query'][] = array(
                            'key'     => $filters_key,
                            'value'   => 'yes', // Assuming 'yes' means true
                            'compare' => '='
                        );
                    }

                    // Handle Publish Date Filtering
                    if (in_array($filters_key, ['_publish_date_from', '_publish_date_to'])) {
                        $compare = ($filters_key === '_publish_date_from') ? '>=' : '<=';
                        $args['date_query'][] = array(
                            'column'  => 'post_date',
                            'value'   => sanitize_text_field($filters_val),
                            'compare' => $compare
                        );
                    }

                    // Handle Product Categories and Tags (Multiple Checkbox)
                    if (in_array($filters_key, ['_product_category', '_product_tag']) && is_array($filters_val)) {
                        $taxonomy = ($filters_key === '_product_category') ? 'product_cat' : 'product_tag';
                        $args['tax_query'][] = array(
                            'taxonomy' => $taxonomy,
                            'field'    => 'term_id',
                            'terms'    => array_map('absint', $filters_val),
                            'operator' => 'IN'
                        );
                    }
                }
            }
        }

        $query = new WP_Query($args);
        $products = [];

        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                global $post;
                $products[] = $this->GMBPU_Table_Value->GMBPU_Value($post->ID, $post);
            }
            wp_reset_postdata();
        }

        return array(
            'status'       => 'success',
            'message'      => 'API call successful',
            'data'         => $products,
            'current_page' => $page,
            'total_pages'  => $query->max_num_pages,
            'header'       => $this->GMBPU_header($data),
            'filter'       => $this->GMBPU_Filter(),
        );
    }


    /**
     * Modify search to restrict it to titles only.
     */
    public function search_by_title_only($search, $wp_query) {
        global $wpdb;

        if (empty($search) || empty($wp_query->query_vars['s'])) {
            return $search;
        }

        $search_term = esc_sql($wp_query->query_vars['s']);
        return " AND {$wpdb->posts}.post_title LIKE '%{$search_term}%'";
    }

    /**
     * Modify search to restrict it to content only.
     */
    public function search_by_content_only($where, $wp_query) {
        global $wpdb;

        if (empty($wp_query->query_vars['s'])) {
            return $where;
        }

        $search_term = esc_sql($wp_query->query_vars['s']);
        return $where . " AND {$wpdb->posts}.post_content LIKE '%{$search_term}%'";
    }

    public function GMBPU_header($data) {
        return $this->GMBPU_Table_Header->GMBPU_header($data);
    }
    public function GMBPU_Filter() {
        return $this->GMBPU_Table_Filter->GMBPU_Filter();
    }
}
