import React from 'react';

// EditableTable component for rendering a table with editable fields
const EditableTable = ({ columns, data, updateMyData }) => {
    // Handle changes in the input fields
    const handleChange = (e, rowIndex, columnId) => {
        const { type, value, checked } = e.target;
        
        // For checkboxes, use the checked state; for other input types, use the value
        const newValue = type === 'checkbox' ? checked : value;

        updateMyData(rowIndex, columnId, newValue); // Call the update function passed from the parent
    };

    return (
        <div className="seachbletable">
        <table >
            <thead>
                <tr>
                    {columns.map((column) => (
                        <th key={column.accessor} >
                            {column.Header}
                        </th>
                    ))}
                </tr>
            </thead>
            <tbody>
                {data.map((row, rowIndex) => (
                    <tr key={rowIndex}>
                        {columns.map((column) => {
                            const value = row[column.accessor];
                            switch (column.inputType) {
                                case 'readonly':
                                    return (
                                        <td key={column.accessor} >
                                            {value}
                                        </td>
                                    );
                                case 'text':
                                case 'number':
                                    return (
                                        <td key={column.accessor} >
                                            <input
                                                type={column.inputType}
                                                value={value || ''}
                                                onChange={(e) => handleChange(e, rowIndex, column.accessor)}
                                                
                                            />
                                        </td>
                                    );
                                case 'select':
                                    return (
                                        <td key={column.accessor} >
                                            <select
                                                value={value || ''}
                                                onChange={(e) => handleChange(e, rowIndex, column.accessor)}
                                                
                                            >
                                                {column.options.map((option) => (
                                                    <option key={option.value} value={option.value}>
                                                        {option.label}
                                                    </option>
                                                ))}
                                            </select>
                                        </td>
                                    );
                                case 'checkbox':
                                    return (
                                        <td key={column.accessor} >
                                            <input
                                                type="checkbox"
                                                checked={value === 'yes' || value === true} // Ensure checkbox is checked based on value
                                                onChange={(e) => handleChange(e, rowIndex, column.accessor)}
                                            />
                                        </td>
                                    );
                                default:
                                    return (
                                        <td key={column.accessor} >
                                            {value}
                                        </td>
                                    );
                            }
                        })}
                    </tr>
                ))}
            </tbody>
        </table>
        </div>
    );
};

export default EditableTable;
